#
# spec file for package libmypaint
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define geglshlib %{name}-gegl0
%define sonum  0
%define girver 1.6
%define shlib %{name}%{sonum}
%bcond_with introspection
Name:           libmypaint
Version:        1.6.1
Release:        2.7
Summary:        A brushstroke creation library
License:        ISC
Group:          Productivity/Graphics/Bitmap Editors
URL:            http://mypaint.org/
Source:         https://github.com/mypaint/libmypaint/releases/download/v%{version}/libmypaint-%{version}.tar.xz
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gegl-0.4)
BuildRequires:  pkgconfig(gobject-2.0)
%if %{with introspection}
BuildRequires:  pkgconfig(gobject-introspection-1.0)
%endif
BuildRequires:  pkgconfig(json-c)

%description
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes
which is used by MyPaint and other projects.

%package -n %{shlib}
Summary:        A brushstroke creation library
Group:          System/Libraries
Provides:       libmypaint = %{version}
Recommends:     %{name}-lang = %{version}

%description -n %{shlib}
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes
which is used by MyPaint and other projects including GIMP 2.9+.
This package provides the shared libraries for %{name}.

%package devel
Summary:        Header files for %{name}, a brushstroke creation library
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
%if %{with introspection}
Requires:       typelib-1_0-MyPaint-%{girver} = %{version}
%endif
Provides:       mypaint-devel = %{version}
Obsoletes:      mypaint-devel < %{version}

%description devel
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes
which is used by MyPaint and other projects.
This package provides the header needed for developing
applications using %{name}.

%package -n typelib-1_0-MyPaint-%{girver}
Summary:        A brushstroke creation library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-MyPaint-%{girver}
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes
which is used by MyPaint and other projects.

This package provides the GObject Introspection bindings for the library.

%package gegl-devel
Summary:        Header files for %{name}, a brushstroke creation library
Group:          Development/Libraries/C and C++
Requires:       %{geglshlib} = %{version}
Requires:       %{shlib} = %{version}
%if %{with introspection}
Requires:       typelib-1_0-MyPaintGegl-%{girver} = %{version}
%endif

%description gegl-devel
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes which
is used by MyPaint and other projects. This package provides the header
files needed for developing applications using the gegl bindings for %{name}.

%package -n %{geglshlib}
Summary:        GEGL bindings for %{name}, a brushstroke creation library
Group:          System/Libraries

%description -n %{geglshlib}
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes which is
used by MyPaint and other projects. This package provides the shared libraries
for %{name}'s GEGL bindings.

%package -n typelib-1_0-MyPaintGegl-%{girver}
Summary:        A brushstroke creation library with gegl support -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-MyPaintGegl-%{girver}
libmypaint, a.k.a. "brushlib", is a library for making brushstrokes
which is used by MyPaint and other projects.

This package provides the GObject Introspection bindings for the library with
gegl support.

%lang_package

%prep
%autosetup -p1

# FIX A SPURIOUS PERM
chmod -x README.md

%build
%configure \
	--enable-gegl \
	--enable-openmp \
%if %{without introspection}
	--disable-introspection \
%endif
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig
%post -n %{geglshlib} -p /sbin/ldconfig
%postun -n %{geglshlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/%{name}.so.*

%files lang -f %{name}.lang

%files devel
%license COPYING
%doc README.md
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/libmypaint.pc
%{_includedir}/%{name}/
%if %{with introspection}
%{_datadir}/gir-1.0/MyPaint-%{girver}.gir
%endif

%files -n %{geglshlib}
%{_libdir}/%{name}-gegl.so.*

%files gegl-devel
%{_libdir}/%{name}-gegl.so
%{_libdir}/pkgconfig/libmypaint-gegl.pc
%{_includedir}/%{name}-gegl/
%if %{with introspection}
%{_datadir}/gir-1.0/MyPaintGegl-%{girver}.gir
%endif

%if %{with introspection}
%files -n typelib-1_0-MyPaint-%{girver}
%{_libdir}/girepository-1.0/MyPaint-%{girver}.typelib

%files -n typelib-1_0-MyPaintGegl-%{girver}
%{_libdir}/girepository-1.0/MyPaintGegl-%{girver}.typelib
%endif

%changelog
* Wed Aug 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Disable introspection building: this fails to build against babl
  0.1.96 and is in fact not used by anything at the moment.
* Sat Apr 23 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.6.1
  * This release contains no code changes just avoiding future
    unnecessary rebuilds of reverse dependencies.
  * Also this release marks the end of including the
    MAJOR.MINOR API version fields in the library names.
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * The new mypaint_brush_stroke_to_2_linearsRGB function.
  * Some performance improvements, particularly improved
  * auto-vectorization in the spectral->rgb conversion function
  * Improved documentation (still lacking a comprehensive
    overview).
  * Updated translations.
- Bump shared lib version in keeping with upstream numbering.
- Define macros for consistent shared object and shlib versioning.
* Mon Feb 24 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.1:
  * mypaint-brush.c:count_dabs_to calculation changed to be
    consistent with v1.3.0 / 1.4.0 when called via the old stroke
    interface, and generally fixed so that there's no need for an
    additional initial mypaint_brush_stroke_to call to produce a
    visible stroke.
  * mypaint-brush.c: estimation of dabs per pixel reverted to the
    old calculation when called via the old stroke interface.
  * Fixes incorrect versions for the requirements in the
    libmypaint-gegl pkg-config file (for both gegl and libmypaint)
  * The openmp flags are now actually used when building with
  - -enable-openmp
  * Translation updates.
- Drop libmypaint-gegl-pkgconfig.patch: incorporated upstream.
- Compile with openmp support by passing `--enable-openmp` to
  configure.
- Build introspection bindings:
  * Add BuildRequires pkgconfig(gobject-introspection-1.0) and
    pkgconfig(glib-2.0).
  * Split out new packages for introspection bindings:
    typelib-1_0-MyPaint-1_5 and typelib-1_0-MyPaintGegl-1_5.
* Tue Feb 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.0:
  * view zoom & view rotation.
  * spectral color blending (pigment mode).
  * new smudge settings: length multiplier, buckets, transparency.
  * new symmetry modes: vertical, vertical+horizontal, rotational,
    snowflake.
  * adjustable angle for symmetry modes.
  * optional multiple output rectangles (only relevant w. new
    symmetry modes).
  * Directional offsets are clamped to a maximum distance of 3 *
    1080 pixels.
- Drop libmypaint-gegl-0.4.14.patch: fixed upstream.
- Drop libmypaint-gegl-shlib-version.patch: incorporated upstream.
- Drop libmypaint-bump-gegl-version.patch: only applicable hunk
  moved to libmypaint-gegl-pkgconfig.patch; rest incorporated
  upstream.
- Add libmypaint-gegl-pkgconfig.patch: In libmypaint-gegl.pc,
  change Name to libmypaint-gegl to avoid conflict with
  libmypaint.pc and Requires to depend on the correct version of
  gegl and on libmypaint - not
  libmypaint-@LIBMYPAINT_API_PLATFORM_VERSION@.
- No longer needed to run autoreconf/autogen.sh before configure
  since patches that modified build files are dropped; also drop
  libtool BuildRequires required only for autoreconf.
- Use autosetup to apply existing patch.
- Bump so version in keeping with upstream (1_5-1).
- Move libmypaint-gegl.pc file to libmypaint-gegl-devel package.
* Wed Sep  4 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.0:
  * Back-port a few new features and bug fixes from the 2.0
    alpha branch.
- Add libmypaint-gegl-shlib-version.patch: Fixes building with
  GEGL Support by removing versioning from the gegl lib
  (gh#mypaint/libmypaint#144).
- Minor refresh of patches to apply cleanly.
- Version Obsoletes for mypaint-devel appropirately to avoid
  self-obsoleting.
- Fix spurious exec perm for README.md file.
* Tue Apr  9 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add libmypaint-gegl-0.4.14.patch: Fix compilation against gegl
  0.4.14 (only for openSUSE >= 15); patch from
  https://www.gimpusers.com/forums/gimp-developer/21248-libmypaint-needs-patching-for-recent-gegl.
* Wed May  2 2018 badshah400@gmail.com
- Provide/Obsolete mypaint-devel: mypaint > 1.2.0 already builds
  against libmypaint [although we don't package the 1.2.x series
  because it doesn't work on openSUSE].
* Mon Apr 30 2018 jengelh@inai.de
- Update descriptions.
* Sat Apr 28 2018 badshah400@gmail.com
- libmypaint, the library, should not obsolete mypaint, the GUI
  application.
- Move libmypaint-lang Recommends and libmypaint-%%%%{version}
  Provides from non-built mainpackage to shared lib subpackage.
- Recommend the same-version lang package.
* Fri Apr 27 2018 bjorn.lie@gmail.com
- Add libmypaint-bump-gegl-version.patch: Bump minimum gegl version
  to new stable branch 0.4.0.
- Following the above, replace pkgconfig(gegl-0.3) with
  pkgconfig(gegl-0.4) and add libtool BuildRequires aswell as pass
  autoreconf since the patch touches the buildsystem.
- Drop currently unused pkgconfig(gobject-2.0) BuildRequires.
- Run spec-cleaner, modernize spec.
* Sat Feb 25 2017 mailaender@opensuse.org
- update to version 1.3.0
* Fri Oct 14 2016 badshah400@gmail.com
- Initial package.
